<?php

namespace Litecms\Comments\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Comments\Models\Comments;

class CommentsPolicy
{

    /**
     * Determine if the given user can view the comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function view(UserPolicy $user, Comments $comments)
    {
        if ($user->canDo('comments.comments.view') && $user->isAdmin()) {
            return true;
        }

        return $comments->user_id == user_id() && $comments->user_type == user_type();
    }

    /**
     * Determine if the given user can create a comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('comments.comments.create');
    }

    /**
     * Determine if the given user can update the given comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function update(UserPolicy $user, Comments $comments)
    {
        if ($user->canDo('comments.comments.edit') && $user->isAdmin()) {
            return true;
        }

        return $comments->user_id == user_id() && $comments->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Comments $comments)
    {
        return $comments->user_id == user_id() && $comments->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Comments $comments)
    {
        if ($user->canDo('comments.comments.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given comments.
     *
     * @param UserPolicy $user
     * @param Comments $comments
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Comments $comments)
    {
        if ($user->canDo('comments.comments.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
